@@ -1,26 +1,23 @@
-// -*- Mode: C++; indent-tabs-mode: nil; c-basic-offset: 2 -*-
-
 /* gstreamermm - a C++ wrapper for gstreamer
  *
  * Copyright 2008 The gstreamermm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
 #include <gstreamermm.h>
-#include <gstreamerbasemm.h>
 #include <iostream>
 
 int main (int argc, char* argv[])
@@ -33,8 +30,8 @@ int main (int argc, char* argv[])
     std::cout << "Successfully created gst element '" <<
       element->get_name() << "'." << std::endl;
 
-  Glib::RefPtr< Gst::ElementInterfaced<GstBase::XOverlay> > xoverlay =
-    Gst::Interface::cast <GstBase::XOverlay>(element);
+  Glib::RefPtr< Gst::ElementInterfaced<Gst::XOverlay> > xoverlay =
+    Gst::Interface::cast <Gst::XOverlay>(element);
 
   if(xoverlay)
   {
